@@ -634,6 +634,11 @@
 #define OMATCOPY_K_RN		DOMATCOPY_K_RN
 #define OMATCOPY_K_CT		DOMATCOPY_K_CT
 #define OMATCOPY_K_RT		DOMATCOPY_K_RT
+#define IMATCOPY_K_CN		DIMATCOPY_K_CN
+#define IMATCOPY_K_RN		DIMATCOPY_K_RN
+#define IMATCOPY_K_CT		DIMATCOPY_K_CT
+#define IMATCOPY_K_RT		DIMATCOPY_K_RT
+
 #define GEADD_K                 DGEADD_K 
 #else
 
@@ -931,6 +936,10 @@
 #define OMATCOPY_K_RN		SOMATCOPY_K_RN
 #define OMATCOPY_K_CT		SOMATCOPY_K_CT
 #define OMATCOPY_K_RT		SOMATCOPY_K_RT
+#define IMATCOPY_K_CN		SIMATCOPY_K_CN
+#define IMATCOPY_K_RN		SIMATCOPY_K_RN
+#define IMATCOPY_K_CT		SIMATCOPY_K_CT
+#define IMATCOPY_K_RT		SIMATCOPY_K_RT
 
 #define GEADD_K 		SGEADD_K 
 #endif
@@ -1747,6 +1756,15 @@
 #define OMATCOPY_K_RNC		ZOMATCOPY_K_RNC
 #define OMATCOPY_K_CTC		ZOMATCOPY_K_CTC
 #define OMATCOPY_K_RTC		ZOMATCOPY_K_RTC
+#define IMATCOPY_K_CN		ZIMATCOPY_K_CN
+#define IMATCOPY_K_RN		ZIMATCOPY_K_RN
+#define IMATCOPY_K_CT		ZIMATCOPY_K_CT
+#define IMATCOPY_K_RT		ZIMATCOPY_K_RT
+#define IMATCOPY_K_CNC		ZIMATCOPY_K_CNC
+#define IMATCOPY_K_RNC		ZIMATCOPY_K_RNC
+#define IMATCOPY_K_CTC		ZIMATCOPY_K_CTC
+#define IMATCOPY_K_RTC		ZIMATCOPY_K_RTC
+
 #define GEADD_K                 ZGEADD_K 
 
 #else
@@ -2160,6 +2178,14 @@
 #define OMATCOPY_K_RNC		COMATCOPY_K_RNC
 #define OMATCOPY_K_CTC		COMATCOPY_K_CTC
 #define OMATCOPY_K_RTC		COMATCOPY_K_RTC
+#define IMATCOPY_K_CN		CIMATCOPY_K_CN
+#define IMATCOPY_K_RN		CIMATCOPY_K_RN
+#define IMATCOPY_K_CT		CIMATCOPY_K_CT
+#define IMATCOPY_K_RT		CIMATCOPY_K_RT
+#define IMATCOPY_K_CNC		CIMATCOPY_K_CNC
+#define IMATCOPY_K_RNC		CIMATCOPY_K_RNC
+#define IMATCOPY_K_CTC		CIMATCOPY_K_CTC
+#define IMATCOPY_K_RTC		CIMATCOPY_K_RTC
 
 #define GEADD_K                 CGEADD_K 
 
