@@ -70,9 +70,11 @@ USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 /*********************************************************************/
 
 #include "common.h"
-#ifdef OS_LINUX
+#if defined(OS_LINUX) || defined(OS_NETBSD) || defined(OS_DARWIN) || defined(OS_ANDROID) || defined(OS_SUNOS)
 #include <dlfcn.h>
+#include <signal.h>
 #include <sys/resource.h>
+#include <sys/time.h>
 #endif
 
 #ifndef likely
@@ -90,6 +92,8 @@ USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #endif
 #endif
 
+extern unsigned int openblas_thread_timeout();
+
 #ifdef SMP_SERVER
 
 #undef MONITOR
@@ -265,7 +269,7 @@ int get_node(void);
 
 static int increased_threads = 0;
 
-static int blas_thread_server(void *arg){
+static void* blas_thread_server(void *arg){
 
   /* Thread identifier */
   BLASLONG  cpu = (BLASLONG)arg;
@@ -425,6 +429,10 @@ static int blas_thread_server(void *arg){
       main_status[cpu] = MAIN_FINISH;
 #endif
 
+      // arm: make sure all results are written out _before_
+      // thread is marked as done and other threads use them
+      WMB;
+
       thread_status[cpu].queue = (blas_queue_t * volatile) ((long)thread_status[cpu].queue & 0);  /* Need a trick */
       WMB;
 
@@ -454,7 +462,7 @@ static int blas_thread_server(void *arg){
 
   //pthread_exit(NULL);
 
-  return 0;
+  return NULL;
 }
 
 #ifdef MONITOR
@@ -518,6 +526,7 @@ static int blas_monitor(void *arg){
 int blas_thread_init(void){
   BLASLONG i;
   int ret;
+  int thread_timeout_env;
 #ifdef NEED_STACKATTR
   pthread_attr_t attr;
 #endif
@@ -534,22 +543,12 @@ int blas_thread_init(void){
 
   if (!blas_server_avail){
 
-    env_var_t p;
-
-    if (readenv(p,"THREAD_TIMEOUT")) {
-      thread_timeout = atoi(p);
-      if (thread_timeout <  4) thread_timeout =  4;
-      if (thread_timeout > 30) thread_timeout = 30;
-      thread_timeout = (1 << thread_timeout);
-    }else{
-		if (readenv(p,"GOTO_THREAD_TIMEOUT")) {
-			thread_timeout = atoi(p);
-			if (thread_timeout <  4) thread_timeout =  4;
-			if (thread_timeout > 30) thread_timeout = 30;
-			thread_timeout = (1 << thread_timeout);
-		}
-	}
-
+    thread_timeout_env=openblas_thread_timeout();
+    if (thread_timeout_env>0) {
+      if (thread_timeout_env <  4) thread_timeout_env =  4;
+      if (thread_timeout_env > 30) thread_timeout_env = 30;
+      thread_timeout = (1 << thread_timeout_env);
+    }
 
     for(i = 0; i < blas_num_threads - 1; i++){
 
@@ -561,14 +560,25 @@ int blas_thread_init(void){
 
 #ifdef NEED_STACKATTR
       ret=pthread_create(&blas_threads[i], &attr,
-		     (void *)&blas_thread_server, (void *)i);
+		     &blas_thread_server, (void *)i);
 #else
       ret=pthread_create(&blas_threads[i], NULL,
-		     (void *)&blas_thread_server, (void *)i);
+		     &blas_thread_server, (void *)i);
 #endif
       if(ret!=0){
-	fprintf(STDERR,"OpenBLAS: pthread_creat error in blas_thread_init function. Error code:%d\n",ret);
-	exit(1);
+	struct rlimit rlim;
+        const char *msg = strerror(ret);
+        fprintf(STDERR, "OpenBLAS blas_thread_init: pthread_create: %s\n", msg);
+#ifdef RLIMIT_NPROC
+        if(0 == getrlimit(RLIMIT_NPROC, &rlim)) {
+          fprintf(STDERR, "OpenBLAS blas_thread_init: RLIMIT_NPROC "
+                  "%ld current, %ld max\n", (long)(rlim.rlim_cur), (long)(rlim.rlim_max));
+        }
+#endif
+        if(0 != raise(SIGINT)) {
+          fprintf(STDERR, "OpenBLAS blas_thread_init: calling exit(3)\n");
+          exit(EXIT_FAILURE);
+        }
       }
     }
 
@@ -775,7 +785,12 @@ int exec_blas(BLASLONG num, blas_queue_t *queue){
   stop = rpcc();
 #endif
 
-  if ((num > 1) && queue -> next) exec_blas_async_wait(num - 1, queue -> next);
+  if ((num > 1) && queue -> next) {
+    exec_blas_async_wait(num - 1, queue -> next);
+
+    // arm: make sure results from other threads are visible
+    MB;
+  }
 
 #ifdef TIMING_DEBUG
   fprintf(STDERR, "Thread[0] : %16lu %16lu (%8lu cycles)\n",
@@ -823,10 +838,10 @@ void goto_set_num_threads(int num_threads) {
 
 #ifdef NEED_STACKATTR
       pthread_create(&blas_threads[i], &attr,
-		     (void *)&blas_thread_server, (void *)i);
+		     &blas_thread_server, (void *)i);
 #else
       pthread_create(&blas_threads[i], NULL,
-		     (void *)&blas_thread_server, (void *)i);
+		     &blas_thread_server, (void *)i);
 #endif
     }
 
