@@ -28,10 +28,16 @@ USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "common.h"
 
-#if defined(BULLDOZER) || defined(PILEDRIVER) || defined(STEAMROLLER)
+#if defined(BULLDOZER) 
 #include "sdot_microk_bulldozer-2.c"
+#elif defined(STEAMROLLER) || defined(PILEDRIVER)  || defined(EXCAVATOR)
+#include "sdot_microk_steamroller-2.c"
 #elif defined(NEHALEM)
 #include "sdot_microk_nehalem-2.c"
+#elif defined(HASWELL)
+#include "sdot_microk_haswell-2.c"
+#elif defined(SANDYBRIDGE)
+#include "sdot_microk_sandy-2.c"
 #endif
 
 
@@ -66,18 +72,20 @@ FLOAT CNAME(BLASLONG n, FLOAT *x, BLASLONG inc_x, FLOAT *y, BLASLONG inc_y)
 {
 	BLASLONG i=0;
 	BLASLONG ix=0,iy=0;
+	double dot = 0.0 ;
 
-	FLOAT  dot = 0.0 ;
+	FLOAT mydot=0.0;
+	BLASLONG n1;
 
 	if ( n <= 0 )  return(dot);
 
 	if ( (inc_x == 1) && (inc_y == 1) )
 	{
 
-		int n1 = n & -16;
+	        n1 = n & (BLASLONG)(-32);
 
 		if ( n1 )
-			sdot_kernel_16(n1, x, y , &dot );
+			sdot_kernel_16(n1, x, y , &mydot );
 
 
 		i = n1;
@@ -88,11 +96,24 @@ FLOAT CNAME(BLASLONG n, FLOAT *x, BLASLONG inc_x, FLOAT *y, BLASLONG inc_y)
 			i++ ;
 
 		}
+		dot+=mydot;
 		return(dot);
 
 
 	}
 
+	n1 = n & (BLASLONG)(-2);
+
+	while(i < n1)
+	{
+
+		dot += y[iy] * x[ix] + y[iy+inc_y] * x[ix+inc_x];
+		ix  += inc_x*2 ;
+		iy  += inc_y*2 ;
+		i+=2 ;
+
+	}
+
 	while(i < n)
 	{
 
@@ -106,4 +127,3 @@ FLOAT CNAME(BLASLONG n, FLOAT *x, BLASLONG inc_x, FLOAT *y, BLASLONG inc_y)
 
 }
 
-
